********************************************************************************
*
* This code runs regressions in Table A3 in the paper "Intergenerational Transmission
* of Fertility: Evidence from China's Population Control Policies"..
*
* Data: Data_Marriage_JoDE.dta
*
* Yongkun Yin, 2024-07-04.
*
********************************************************************************


clear

** set directory
* main folder
global mainPath "E:/Dropbox/IGTF Replication"

* Stata fo files folder
global doPath "$mainPath/Stata Files"

* original data folder
global dataPath "$mainPath/Data"

* results folder
global resultsPath "$mainPath/Results"


use "$dataPath/Data_Marriage_JoDE.dta", clear

cd "$dataPath/Results"


tab age, gen(iage)

tab prov_12, gen(iprov)

egen cluster_group = group(prov_12 age)


**** Table A3. The number of siblings and marriage/cohabition

est clear

* OLS

ivreg2 union sib iage1-iage83 iprov1-iprov31 if mbirthy>=1920 & mbirthy<1964 & gender==1 & age<=48 [pw = rswt_nat], cluster(cluster_group)
estadd ysumm
est store m1

ivreg2 union sib yr_school minority urban_hukou_12 iage1-iage83 iprov1-iprov31 if mbirthy>=1920 & mbirthy<1964 & gender==1 & age<=48 [pw = rswt_nat], cluster(cluster_group)
estadd ysumm
est store m2

ivreg2 union sib iage1-iage83 iprov1-iprov31 if mbirthy>=1920 & mbirthy<1964 & gender==0 & age<=46 [pw = rswt_nat], cluster(cluster_group)
estadd ysumm
est store m3

ivreg2 union sib yr_school minority urban_hukou_12 iage1-iage83 iprov1-iprov31 if mbirthy>=1920 & mbirthy<1964 & gender==0 & age<=46 [pw = rswt_nat], cluster(cluster_group)
estadd ysumm
est store m4

* 2SLS

ivreg2 union (sib = exp_llf exp_ocp) iage1-iage83 iprov1-iprov31 if mbirthy>=1920 & mbirthy<1964 & gender==1 & age<=48 [pw = rswt_nat], cluster(cluster_group)
estadd ysumm
est store m5

ivreg2 union (sib = exp_llf exp_ocp) yr_school minority urban_hukou_12 iage1-iage83 iprov1-iprov31 if mbirthy>=1920 & mbirthy<1964 & gender==1 & age<=48 [pw = rswt_nat], cluster(cluster_group)
estadd ysumm
est store m6

ivreg2 union (sib = exp_llf exp_ocp) iage1-iage83 iprov1-iprov31 if mbirthy>=1920 & mbirthy<1964 & gender==0 & age<=46 [pw = rswt_nat], cluster(cluster_group)
estadd ysumm
est store m7

ivreg2 union (sib = exp_llf exp_ocp) yr_school minority urban_hukou_12 iage1-iage83 iprov1-iprov31 if mbirthy>=1920 & mbirthy<1964 & gender==0 & age<=46 [pw = rswt_nat], cluster(cluster_group)
estadd ysumm

est store m8

esttab m1 m2 m3 m4 m5 m6 m7 m8 using Table_marriage.rtf, replace b(3) se(3) r2 star(* 0.1 ** 0.05 *** 0.01) keep (sib yr_school minority urban_hukou_12) order(sib yr_school minority urban_hukou_12) label stats(N r2 ymean rkf)

esttab m1 m2 m3 m4 m5 m6 m7 m8 using Table_marriage.tex, replace b(3) se(3) r2 star(* 0.1 ** 0.05 *** 0.01) keep (sib yr_school minority urban_hukou_12) order(sib yr_school minority urban_hukou_12) label stats(N r2 ymean rkf)


